Bootstrap 101 Template

--- layout: default title: Getting started slug: getting-started lead: "An overview of Bootstrap, how to download and use, basic templates and examples, and more." base_url: "../" ---

# Download Bootstrap

Bootstrap has a few easy ways to quickly get started, each one appealing to a different skill level and use case. Read through to see what suits your particular needs.

### Compiled CSS, JS, and fonts

The fastest way to get Bootstrap is to download the precompiled and minified versions of our CSS, JavaScript, and fonts. No documentation or original source code files are included.

Download precompiled Bootstrap

### Additional downloads

#### Download source code

Get the latest Bootstrap LESS and JavaScript source code by downloading it directly from GitHub.

#### Clone or fork via GitHub

Visit us on GitHub to clone or fork the Bootstrap project.

#### Install with Bower

Install and manage Bootstrap's styles, JavaScript, and documentation using Bower.

{% highlight bash %}$ bower install bootstrap{% endhighlight %}

### Bootstrap CDN

The folks over at NetDNA graciously provide CDN support for Bootstrap's CSS and JavaScript. Just use these Bootstrap CDN links.

{% highlight html %}
{% endhighlight %}

#### Compiling Bootstrap's LESS files

If you work with Bootstrap's uncompiled source code, you need to compile the LESS files to produce usable CSS files. For compiling LESS files into CSS, we only officially support Recess, which is Twitter's CSS hinter based on less.js.

# What's included

Within the download you'll find the following directories and files, logically grouping common assets and providing both compiled and minified variations.

Once downloaded, unzip the compressed folder to see the structure of (the compiled) Bootstrap. You'll see something like this:

{% highlight bash %} bootstrap/ ├── css/ │ ├── bootstrap.css │ ├── bootstrap.min.css │ ├── bootstrap-theme.css │ └── bootstrap-theme.min.css ├── js/ │ ├── bootstrap.js │ └── bootstrap.min.js └── fonts/ ├── glyphicons-halflings-regular.eot ├── glyphicons-halflings-regular.svg ├── glyphicons-halflings-regular.ttf └── glyphicons-halflings-regular.woff {% endhighlight %}

This is the most basic form of Bootstrap: precompiled files for quick drop-in usage in nearly any web project. We provide compiled CSS and JS (`bootstrap.*`), as well as compiled and minified CSS and JS (`bootstrap.min.*`). Fonts from Glyphicons are included, as is the optional Bootstrap theme.

#### jQuery required

Please note that all JavaScript plugins require jQuery to be included, as shown in the starter template.

# Basic template

Start with this basic HTML template, or modify these examples. We hope you'll customize our templates and examples, adapting them to suit your needs.

Copy the HTML below to begin working with a minimal Bootstrap document.

{% highlight html %}

# Hello, world!

{% endhighlight %}

# Examples

Build on the basic template above with Bootstrap's many components. See also Customizing Bootstrap for tips on maintaining your own Bootstrap variants.

#### Starter template

Nothing but the basics: compiled CSS and JavaScript along with a container.

#### Grids

Multiple examples of grid layouts with all four tiers, nesting, and more.

#### Jumbotron

Build around the jumbotron with a navbar and some basic grid columns.

#### Narrow jumbotron

Build a more custom page by narrowing the default container and jumbotron.

#### Navbar

Super basic template that includes the navbar along with some additional content.

#### Static top navbar

Super basic template with a static top navbar along with some additional content.

#### Fixed navbar

Super basic template with a fixed top navbar along with some additional content.

#### Sign-in page

Custom form layout and design for a simple sign in form.

#### Sticky footer

Attach a footer to the bottom of the viewport when the content is shorter than it.

#### Sticky footer with navbar

Attach a footer to the bottom of the viewport with a fixed navbar at the top.

#### Justified nav

Create a custom navbar with justified links. Heads up! Not too WebKit friendly.

#### Offcanvas

Build a toggleable off-canvas navigation menu for use with Bootstrap.

#### Carousel

Customize the navbar and carousel, then add some new components.

#### Non-responsive Bootstrap

Easily disable the responsiveness of Bootstrap per our docs.

#### Bootstrap theme

Load the optional Bootstrap theme for a visually enhanced experience.

# Disabling responsiveness

Bootstrap automatically adapts your pages for various screen sizes. Here's how to disable this feature so your page works like in this non-responsive example.

### Steps to disable page responsiveness

1. Omit the viewport `<meta>` mentioned in the CSS docs
2. Override the `width` on the `.container` for each grid tier with a single width, for example `width: 970px !important;` Be sure that this comes after the default Bootstrap CSS. You can optionally avoid the `!important` with media queries or some selector-fu.
3. If using navbars, remove all navbar collapsing and expanding behavior.
4. For grid layouts, use `.col-xs-*` classes in addition to, or in place of, the medium/large ones. Don't worry, the extra-small device grid scales to all resolutions.

You'll still need Respond.js for IE8 (since our media queries are still there and need to be processed). This disables the "mobile site" aspects of Bootstrap.

### Bootstrap template with responsiveness disabled

We've applied these steps to an example. Read its source code to see the specific changes implemented.

View non-responsive example

# Migrating from 2.x to 3.0

Bootstrap 3 is not backwards compatible with v2.x. Use this section as a general guide to upgrading from v2.x to v3.0. For a broader overview, see what's new in the v3.0 release announcement.

## Major class changes

This table shows the style changes between v2.x and v3.0.

Bootstrap 2.x | Bootstrap 3.0
--- | ---
`.container-fluid` | `.container`
`.row-fluid` | `.row`
`.span*` | `.col-md-*`
`.offset*` | `.col-md-offset-*`
`.brand` | `.navbar-brand`
`.nav-collapse` | `.navbar-collapse`
`.nav-toggle` | `.navbar-toggle`
`.btn-navbar` | `.navbar-btn`
`.hero-unit` | `.jumbotron`
`.icon-*` | `.glyphicon .glyphicon-*`
`.btn` | `.btn .btn-default`
`.btn-mini` | `.btn-xs`
`.btn-small` | `.btn-sm`
`.btn-large` | `.btn-lg`
`.alert-error` | `.alert-danger`
`.visible-phone` | `.visible-xs`
`.visible-tablet` | `.visible-sm`
`.visible-desktop` | `.visible-md`
`.hidden-phone` | `.hidden-xs`
`.hidden-tablet` | `.hidden-sm`
`.hidden-desktop` | `.hidden-md`
`.input-small` | `.input-sm`
`.input-large` | `.input-lg`
`.checkbox.inline` `.radio.inline` | `.checkbox-inline` `.radio-inline`
`.input-prepend` `.input-append` | `.input-group`
`.add-on` | `.input-group-addon`
`.thumbnail` | `.img-thumbnail`
`ul.unstyled` | `.list-unstyled`
`ul.inline` | `.list-inline`
`.muted` | `.text-muted`
`.text-error` | `.text-danger`
`.table .error` | `.table .danger`
`.bar` | `.progress-bar`
`.bar-*` | `.progress-bar-*`

## What's new

We've added new elements and changed some existing ones. Here are the new or updated styles.

Element | Description
--- | ---
Panels | `.panel .panel-default` `.panel-body` `.panel-title` `.panel-heading` `.panel-footer` `.panel-collapse`
List groups | `.list-group` `.list-group-item` `.list-group-item-text` `.list-group-item-heading`
Glyphicons | `.glyphicon`
Jumbotron | `.jumbotron`
Extra small grid (<768px) | `.col-xs-*`
Small grid (≥768px) | `.col-sm-*`
Medium grid (≥992px) | `.col-md-*`
Large grid (≥1200px) | `.col-lg-*`
Responsive utility classes (≥1200px) | `.visible-lg` `.hidden-lg`
Offsets | `.col-sm-offset-*` `.col-md-offset-*` `.col-lg-offset-*`
Push | `.col-sm-push-*` `.col-md-push-*` `.col-lg-push-*`
Pull | `.col-sm-pull-*` `.col-md-pull-*` `.col-lg-pull-*`
Input groups | `.input-group` `.input-group-addon` `.input-group-btn`
Form controls | `.form-control` `.form-group`
Button group sizes | `.btn-group-xs` `.btn-group-sm` `.btn-group-lg`
Navbar text | `.navbar-text`
Navbar header | `.navbar-header`
Justified tabs / pills | `.nav-justified`
Responsive images | `.img-responsive`
Contextual table rows | `.success` `.danger` `.warning` `.active`
Contextual panels | `.panel-success` `.panel-danger` `.panel-warning` `.panel-info`
Modal | `.modal-dialog` `.modal-content`
Thumbnail image | `.img-thumbnail`
Well sizes | `.well-sm` `.well-lg`
Alert links | `.alert-link`

## What's removed

The following elements have been dropped or changed in v3.0.

Element | Removed from 2.x | 3.0 Equivalent
--- | --- | ---
Form actions | `.form-actions` | N/A
Search form | `.form-search` | N/A
Fluid container | `.container-fluid` | `.container` (no more fixed grid)
Fluid row | `.row-fluid` | `.row` (no more fixed grid)
Navbar inner | `.navbar-inner` | N/A
Navbar vertical dividers | `.navbar .divider-vertical` | N/A
Dropdown submenu | `.dropdown-submenu` | N/A
Tab alignments | `.tabs-left` `.tabs-right` `.tabs-below` | N/A
Nav lists | `.nav-list` `.nav-header` | No direct equivalent, but List groups and `.panel-group`s are similar.

## Additional notes

Other changes in v3.0 are not immediately apparent. Base classes, key styles, and behaviors have been adjusted for flexibility and our mobile first approach. Here's a partial list:

- Text-based form controls are now 100% wide. Wrap inputs inside `<div class="col-*"></div>` to control input widths.
- `.badge` no longer has contextual (-success,-primary,etc..) classes.
- `.btn` must also use `.btn-default` to get the "default" button.
- `.container` and `.row` are now fluid (percentage-based).
- Images are no longer responsive by default. Use `.img-responsive` for fluid `<img>` size.
- The icons, now `.glyphicon`, are now font based. Icons also require a base and icon class (e.g. `.glyphicon .glyphicon-asterisk`).
- Typeahead has been dropped, in favor of using Twitter Typeahead.
- Modal markup has changed significantly. The `.modal-header`, `.modal-body`, and `.modal-footer` sections are now wrapped in `.modal-content` and `.modal-dialog` for better mobile styling and behavior.
- JavaScript events are namespaced. For example, to handle the modal "show" event, use `'show.bs.modal'`. For tabs "shown" use `'shown.bs.tab'`, etc..

For more information on upgrading to v3.0, and code snippets from the community, see Bootply.

# Browser support

Bootstrap is built to work best in the latest desktop and mobile browsers, meaning older browsers might display differently styled, though fully functional, renderings of certain components.

### Supported browsers

Specifically, we support the latest versions of the following:

- Chrome (Mac, Windows, iOS, and Android)
- Safari (Mac and iOS only, as the Windows version is being abandoned)
- Firefox (Mac, Windows)
- Internet Explorer
- Opera (Mac, Windows)

Unofficially, Bootstrap should look and behave well enough in Chromium for Linux, Firefox for Linux, and Internet Explorer 7, though they are not officially supported.

### Internet Explorer 8 and 9

Internet Explorer 8 and 9 are also supported, however, please be aware that some CSS3 properties and HTML5 elements are not fully supported by these browsers. In addition, Internet Explorer 8 requires the use of respond.js to enable media query support.

Feature | Internet Explorer 8 | Internet Explorer 9
--- | --- | ---
`border-radius` | Not supported | Supported
`box-shadow` | Not supported | Supported
`transform` | Not supported | Supported, with `-ms` prefix
`transition` | Not supported
`placeholder` | Not supported

Visit Can I use... for details on browser support of CSS3 and HTML5 features.

### Internet Explorer 8 and box-sizing

IE8 does not fully support `box-sizing: border-box;` when combined with `min-width`, `max-width`, `min-height`, or `max-height`. For that reason, as of v3.0.1, we no longer use `max-width` on `.container`s.

### IE Compatibility modes

Bootstrap is not supported in the old Internet Explorer compatibility modes. To be sure you're using the latest rendering mode for IE, consider including the appropriate `<meta>` tag in your pages:

{% highlight html %} {% endhighlight %}

See this StackOverflow question for more information.

### Windows Phone 8 and Internet Explorer 10

Internet Explorer 10 doesn't differentiate device width from viewport width, and thus doesn't properly apply the media queries in Bootstrap's CSS. To address this, you can optionally include the following CSS and JavaScript to work around this problem until Microsoft issues a fix.

{% highlight css %} @-webkit-viewport { width: device-width; } @-moz-viewport { width: device-width; } @-ms-viewport { width: device-width; } @-o-viewport { width: device-width; } @viewport { width: device-width; } {% endhighlight %} {% highlight js %} if (navigator.userAgent.match(/IEMobile\/10\.0/)) { var msViewportStyle = document.createElement("style") msViewportStyle.appendChild( document.createTextNode( "@-ms-viewport{width:auto!important}" ) ) document.getElementsByTagName("head")[0].appendChild(msViewportStyle) } {% endhighlight %}

For more information and usage guidelines, read Windows Phone 8 and Device-Width.

### Safari percent rounding

In the latest Safari for Mac, its rendering engine has a little trouble with the long decimal places of our `.col-*-1` grid classes, meaning if you have 12 individual columns you'll notice they come up short compared to other rows of columns. We can't do much here (see #9282) but you do have some options:

- Add `.pull-right` to your last grid column to get the hard-right alignment
- Tweak your percentages manually to get the perfect rounding for Safari (more difficult than the first option)

We'll keep an eye on this though and update our code if we have an easy solution.

### Modals and mobile devices

#### Overflow and scrolling

Support for `overflow: hidden` on the `<body>` element is quite limited in iOS and Android. To that end, when you scroll past the top or bottom of a modal in either of those devices' browsers, the `<body>` content will begin to scroll.

#### Virtual keyboards

Also, note that if you're using inputs in your modal – iOS has a rendering bug that doesn't update the position of fixed elements when the virtual keyboard is triggered. A few work arounds for this include transforming your elements to `position: absolute` or invoking a timer on focus to try to correct the positioning manually. This is not handled by Bootstrap, so it is up to you to decide which solution is best for your application.

### Browser zooming

Page zooming inevitably presents rendering artifacts in some components, both in Bootstrap and the rest of the web. Depending on the issue, we may be able to fix it (search first and then open an issue if need be). However, we tend to ignore these as they often have no direct solution other than hacky workarounds.

# Third party support

While we don't officially support any third party plugins or add-ons, we do offer some useful advice to help avoid potential issues in your projects.

### Box-sizing

Some third party software, including Google Maps and Google Custom Search Engine, conflict with Bootstrap due to `* { box-sizing: border-box; }`, a rule which makes it so `padding` does not affect the final computed width of an element. Learn more about box model and sizing at CSS Tricks.

Depending on the context, you may override as-needed (Option 1) or reset the box-sizing for entire regions (Option 2).

{% highlight css %} /* Box-sizing resets * * Reset individual elements or override regions to avoid conflicts due to * global box model settings of Bootstrap. Two options, individual overrides and * region resets, are available as plain CSS and uncompiled LESS formats. */ /* Option 1A: Override a single element's box model via CSS */ .element { -webkit-box-sizing: content-box; -moz-box-sizing: content-box; box-sizing: content-box; } /* Option 1B: Override a single element's box model by using a Bootstrap LESS mixin */ .element { .box-sizing(content-box); } /* Option 2A: Reset an entire region via CSS */ .reset-box-sizing, .reset-box-sizing *, .reset-box-sizing *:before, .reset-box-sizing *:after { -webkit-box-sizing: content-box; -moz-box-sizing: content-box; box-sizing: content-box; } /* Option 2B: Reset an entire region with a custom LESS mixin */ .reset-box-sizing { &, *, *:before, *:after { .box-sizing(content-box); } } .element { .reset-box-sizing(); } {% endhighlight %}

# Accessibility

Bootstrap follows common web standards, and with minimal extra effort, can be used to create sites that are accessibile to those using AT.

### Skip navigation

If your navigation contains many links and comes before the main content in the DOM, add a `Skip to content` link immediately after your opening `<body>` tag. (read why)

{% highlight html %}
Skip to content
The main page content.
{% endhighlight %}

### Nested headings

When nesting headings (`<h1>` - `<h6>`), your primary document header should be an `<h1>`. Subsequent headings should make logical use of `<h2>` - `<h6>` such that screen readers can construct a table of contents for your pages.

Learn more at HTML CodeSniffer and Penn State's AccessAbility.

### Additional resources

- "HTML Codesniffer" bookmarklet for identifying accessibility issues
- The A11Y Project
- MDN accessibility documentation

# License FAQs

Bootstrap is released under the Apache 2 license and is copyright {{ site.time | date: "%Y" }} Twitter. Boiled down to smaller chunks, it can be described with the following conditions.

#### It allows you to:

- Freely download and use Bootstrap, in whole or in part, for personal, company internal or commercial purposes
- Use Bootstrap in packages or distributions that you create

#### It forbids you to:

- Redistribute any piece of Bootstrap without proper attribution
- Use any marks owned by Twitter in any way that might state or imply that Twitter endorses your distribution
- Use any marks owned by Twitter in any way that might state or imply that you created the Twitter software in question

#### It requires you to:

- Include a copy of the license in any redistribution you may make that includes Bootstrap
- Provide clear attribution to Twitter for any distributions that include Bootstrap

#### It does not require you to:

- Include the source of Bootstrap itself, or of any modifications you may have made to it, in any redistribution you may assemble that includes it
- Submit changes that you make to Bootstrap back to the Bootstrap project (though such feedback is encouraged)

The full Bootstrap license is located in the project repository for more information.

# Customizing Bootstrap

Bootstrap is best maintained when you treat it as a separate and independently-versioned dependency in your development environment. Doing this makes upgrading Bootstrap easier in the future.

Once you've downloaded and included Bootstrap's styles and scripts, you can customize its components. Just create a new stylesheet (LESS, if you like, or just plain CSS) to house your customizations.

#### Compiled or minified?

Unless you plan on reading the CSS, go with minified stylesheets. It's the same code, just compacted. Minified styles use less bandwidth, which is good, especially in production environments.

From there, include whatever Bootstrap components and HTML content you need to create templates for your site's pages.

### Customizing components

You can customize components to varying degrees, but most fall into two camps: light customizations and overhauls. Plenty examples of both are available from third parties.

We define light customizations as superficial changes, for example, color and font changes to existing Bootstrap components. A light customization example is the Twitter Translation Center (coded by @mdo). Let's look at how to implement the custom button we wrote for this site, `.btn-ttc`.

The stock Bootstrap buttons require just one class, `.btn`, to start. Here we extend the `.btn` style with a new modifier class, `.btn-ttc`, that we will create. This gives us a distinct custom look with minimal effort.

Our customized button will be coded like this:

{% highlight html %}
{% endhighlight %}

Note how `.btn-ttc` is added to the standard `.btn` class.

To implement this, in the custom stylesheet, add the following CSS:

{% highlight css %} /* Custom button -------------------------------------------------- */ /* Override base .btn styles */ /* Apply text and background changes to three key states: default, hover, and active (click). */ .btn-ttc, .btn-ttc:hover, .btn-ttc:active { color: white; text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25); background-color: #007da7; } /* Apply the custom-colored gradients */ /* Note: you'll need to include all the appropriate gradients for various browsers and standards. */ .btn-ttc { background-repeat: repeat-x; background-image: linear-gradient(top, #009ED2 0%, #007DA7 100%); ... } /* Set the hover state */ /* An easy hover state is just to move the gradient up a small amount. Add other embellishments as you see fit. */ .btn-ttc:hover { background-position: 0 -15px; } {% endhighlight %}

In short: Look to the style source and duplicate the selectors you need for your modifications.

In summary, here's the basic workflow:

- For each element you want to customize, find its code in the compiled Bootstrap CSS.
- Copy the component's selector and styles and paste them in your custom stylesheet. For instance, to customize the navbar background, just copy the `.navbar` style specificaton.
- In your custom stylesheet, edit the CSS you just copied from the Bootstrap source. No need for prepending additional classes, or appending `!important` here. Keep it simple.
- Rinse and repeat until you're happy with your customizations.

Once you are comfortable performing light customizations, visual overhauls are just as straightforward. For a site like Karma, which uses Bootstrap as a CSS reset with heavy modifications, more extensive work is involved. But the same principle applies: include Bootstrap's default stylesheet first, then apply your custom stylesheet.

#### Alternate customization methods

While not recommended for folks new to Bootstrap, you may use one of two alternate methods for customization. The first is modifying the source `.less` files (making upgrades super difficult), and the second is mapping source LESS code to your own classes via mixins. For the time being, neither of those options are documented here.

### Removing potential bloat

Not all sites and applications need to make use of everything Bootstrap has to offer, especially in production environments where optimizing bandwidth is an issue. We encourage you to remove whatever is unused with our Customizer.

Using the Customizer, simply uncheck any component, feature, or asset you don't need. Hit download and swap out the default Bootstrap files with these newly customized ones. You'll get vanilla Bootstrap, but without the features *you* deem unnecessary. All custom builds include compiled and minified versions, so use whichever works for you.